==> alfred-ui-native-components-0.0.90.tgz: package/ui/widgets/details/shutter/components/slatsControlPanel/index.tsx <==
import React, { FC } from 'react';
import { View } from 'react-native';
import { ArrowDownIcon, 
  ArrowUpIcon, 
  Body2RegularText, 
  LabelRegularText, 
  PrimaryExtraLargeIconFlatButton, 
  SecondaryExtraLargeIconFlatButton, 
  StopIcon } from '../../../../../atoms';
import { ShutterControlPanelValue, SlatsControlPanelModel } from '../shutterModels';
import { styles } from '../styles';

const slatsControlPanelValues: { [key: string]: ShutterControlPanelValue } = {
  DOWN: 'DOWN',
  STOP: 'STOP',
  UP: 'UP',
};

export const SlatsControlPanel: FC<SlatsControlPanelModel> = ({
  title,
  value,
  onClick,
  loading: isLoading,
}) => {
  return (
    <View style={styles.controlPanelWrapper}>
      <View style={styles.controlPanelTitle}>
        <LabelRegularText color={styles.controlPanelTitle.color}>{title}</LabelRegularText>
      </View>
      <View>
        <View style={styles.controlPanelInfo}>
          <View>
            <Body2RegularText color={styles.controlPanelInfoSubtitle.color}>
              {`${value}º`}
            </Body2RegularText>
          </View>
        </View>
        <View style={styles.controlPanelControlsWrapper}>
          <View
            style={styles.controlPanelControls}
          >
            <PrimaryExtraLargeIconFlatButton
              Icon={ArrowDownIcon}
              disabled={isLoading}
              onClick={() => onClick?.(slatsControlPanelValues.DOWN)}
            />
            <SecondaryExtraLargeIconFlatButton
              Icon={StopIcon}
              disabled={isLoading}
              onClick={() => onClick?.(slatsControlPanelValues.STOP)}
            />
            <PrimaryExtraLargeIconFlatButton
              Icon={ArrowUpIcon}
              disabled={isLoading}
              onClick={() => onClick?.(slatsControlPanelValues.UP)}
            />
          </View>
        </View>
      </View>
    </View>
  );
};

==> alfred-ui-native-components-0.0.166.tgz: package/ui/widgets/details/shutter/components/slatsControlPanel/index.tsx <==
import React, { FC } from 'react';
import { View } from 'react-native';
import { ArrowDownIcon,
  ArrowUpIcon,
  Body2RegularText,
  LabelRegularText,
  PrimaryExtraLargeIconFlatButton,
  SecondaryExtraLargeIconFlatButton,
  StopIcon } from '../../../../../atoms';
import { ShutterControlPanelValue, SlatsControlPanelModel } from '../shutterModels';
import { styles } from '../styles';

const slatsControlPanelValues: { [key: string]: ShutterControlPanelValue } = {
  DOWN: 'DOWN',
  STOP: 'STOP',
  UP: 'UP',
};

export const SlatsControlPanel: FC<SlatsControlPanelModel> = ({
  title,
  value,
  onClick,
  loading: isLoading,
}) => {
  return (
    <View style={styles().controlPanelWrapper}>
      <View style={styles().controlPanelTitle}>
        <LabelRegularText color={styles().controlPanelTitle.color}>{title}</LabelRegularText>
      </View>
      <View>
        <View style={styles().controlPanelInfo}>
          <View>
            <Body2RegularText color={styles().controlPanelInfoSubtitle.color}>
              {`${value}º`}
            </Body2RegularText>
          </View>
        </View>
        <View style={styles().controlPanelControlsWrapper}>
          <View
            style={styles().controlPanelControls}
          >
            <PrimaryExtraLargeIconFlatButton
              Icon={ArrowDownIcon}
              disabled={isLoading}
              onClick={() => onClick?.(slatsControlPanelValues.DOWN)}
            />
            <SecondaryExtraLargeIconFlatButton
              Icon={StopIcon}
              disabled={isLoading}
              onClick={() => onClick?.(slatsControlPanelValues.STOP)}
            />
            <PrimaryExtraLargeIconFlatButton
              Icon={ArrowUpIcon}
              disabled={isLoading}
              onClick={() => onClick?.(slatsControlPanelValues.UP)}
            />
          </View>
        </View>
      </View>
    </View>
  );
};
